summaryrefslogtreecommitdiffstats
path: root/kparts/factory.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /kparts/factory.h
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kparts/factory.h')
-rw-r--r--kparts/factory.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kparts/factory.h b/kparts/factory.h
index c1b98eca1..2ac834ba4 100644
--- a/kparts/factory.h
+++ b/kparts/factory.h
@@ -60,7 +60,7 @@ public:
* \endcode
* This could result in a call to
* \code
* createPart( parentWidget, name, parentObject, parentName, "KParts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
*
@@ -71,7 +71,7 @@ public:
* important for reference counting, and allows unloading the
* library automatically once all its objects have been destroyed.
*/
- Part *createPart( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() );
+ Part *createPart( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() );
/**
* If you have a part contained in a shared library you might want to query
@@ -108,13 +108,13 @@ protected:
* \endcode
* This could result in a call to
* \code
* createPart( parentWidget, name, parentObject, parentName, "Kparts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
*
* @returns the newly created part.
*/
- virtual Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() ) = 0;
+ virtual Part *createPartObject( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() ) = 0;
/**
* Reimplemented from KLibFactory. Calls createPart()
@@ -60,7 +60,7 @@ public:
* This could result in a call to
* \code
- * createPart( parentWidget, name, parentObject, parentName, "KParts::Part",
+ * createPart( tqparentWidget, name, parentObject, parentName, "KParts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
@@ -108,13 +108,13 @@ protected:
* This could result in a call to
* \code
- * createPart( parentWidget, name, parentObject, parentName, "Kparts::Part",
+ * createPart( tqparentWidget, name, parentObject, parentName, "Kparts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode